==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/SAPDB/SQLStudio/WebQuery/StudioWeb_TemplateParamQuery.cpp <==
/*!**********************************************************************w

  module: StudioWeb_Template.cpp

  -----------------------------------------------------------------------

  responsible:  WolfgangA

  special area: WebQuery

  description:  logon mask class for WebQuery

  see also:		/

  -----------------------------------------------------------------------

  copyright:                Copyright by SAP AG, 2000



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

************************************************************************/
/*-----------------------------------------------------------------------------
  includes
-----------------------------------------------------------------------------*/
#include <stdio.h>
#include "SQLStudio/WebQuery/StudioWeb_TemplateParamQuery.hpp"

/*-----------------------------------------------------------------------------
  defines
 -----------------------------------------------------------------------------*/
#define TEMPLATE_NAME     "wqparamquery.htm"

#define OBJ_PARAMSTATEMENT  "ParamStatement"
#define OBJ_ONEPARAM		"OneParam"
#define OBJ_ONEPARAMTEXT    "OneParamText"
#define OBJ_ONEPARAMINPUTNAME	"OneParamInputName"



StudioWeb_TemplateParamQuery::StudioWeb_TemplateParamQuery (sapdbwa_WebAgent & wa) 
: SAPDBWeb_Template (wa,TEMPLATE_NAME)
                      
{ 
	m_nParams = 0;
	m_nCurrentParam = 0;
	m_nCurrentParamText = 0;
	m_nCurrentParamInputName = 0;
	
} 

void StudioWeb_TemplateParamQuery::setParam(const SAPDB_DynamicUTF8String &sParamText)
{
	++m_nParams;	
	
	m_ParamText[m_nParams] = sParamText;	

	m_ParamInputName[m_nParams] = (SAPDB_UTF8*)"T";
	//sBuffer contains a number, which can be represented in ascii7 => cast to (SAPDB_UTF8*) is valid
	char	sBuffer[64];
	sprintf(sBuffer,"%d",m_nParams);				
	m_ParamInputName[m_nParams].Append((SAPDB_UTF8*)sBuffer);	

	
}



SAPDB_Int2 StudioWeb_TemplateParamQuery::askForWriteCount(const SAPDB_Char * szName)
{
  SAPDB_Int2 nReturn = 0;

  if (strcmp(szName, OBJ_ONEPARAM) == 0) {
    //nReturn = (m_nCurrentParam < m_nParams) ? 1 : 0;
	  nReturn = m_nParams;
    ++m_nCurrentParam;
  }
  else if (strcmp(szName, OBJ_ONEPARAMTEXT) == 0) {
    nReturn = 1;
  }
  else if (strcmp(szName, OBJ_ONEPARAMINPUTNAME) == 0) {
    nReturn = 1;
  } // end if
  else if (strcmp(szName, OBJ_PARAMSTATEMENT) == 0) {
    nReturn = 1;
  } // end if
  

  return nReturn;
} 


const SAPDBWeb_String StudioWeb_TemplateParamQuery::askForValue (const SAPDB_Char *szName)
{
  
  if (strcmp(szName, OBJ_ONEPARAM) == 0) {

	  return "";	  
  } 
  else if (strcmp(szName, OBJ_ONEPARAMTEXT) == 0) {

	  ++m_nCurrentParamText;
	  return  m_ParamText[m_nCurrentParamText];	  
  } 
  else if (strcmp(szName, OBJ_ONEPARAMINPUTNAME) == 0) {

	  ++m_nCurrentParamInputName;	
	  return m_ParamInputName[m_nCurrentParamInputName];
  }
  else if (strcmp(szName, OBJ_PARAMSTATEMENT) == 0) {

    return m_sStatement;
  } 	

  return "";
}

void StudioWeb_TemplateParamQuery::resetStartValues ()
{
	m_nCurrentParam = 0;
	m_nCurrentParamText = 0;
	m_nCurrentParamInputName = 0;
}

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/SAPDB/SQLStudio/WebQuery/StudioWeb_TemplateParamQuery.cpp <==
/*!**********************************************************************w

  module: StudioWeb_Template.cpp

  -----------------------------------------------------------------------

  responsible:  WolfgangA

  special area: WebQuery

  description:  logon mask class for WebQuery

  see also:		/

  -----------------------------------------------------------------------

  copyright:                Copyright by SAP AG, 2000



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

************************************************************************/
/*-----------------------------------------------------------------------------
  includes
-----------------------------------------------------------------------------*/
#include <stdio.h>
#include "SQLStudio/WebQuery/StudioWeb_TemplateParamQuery.hpp"

/*-----------------------------------------------------------------------------
  defines
 -----------------------------------------------------------------------------*/
#define TEMPLATE_NAME     "wqparamquery.htm"

#define OBJ_PARAMSTATEMENT  "ParamStatement"
#define OBJ_ONEPARAM		"OneParam"
#define OBJ_ONEPARAMTEXT    "OneParamText"
#define OBJ_ONEPARAMINPUTNAME	"OneParamInputName"



StudioWeb_TemplateParamQuery::StudioWeb_TemplateParamQuery (sapdbwa_WebAgent & wa) 
: Tools_Template (wa,_Tools_UTF8Ptr(TEMPLATE_NAME))
                      
{ 
	m_nParams = 0;
	m_nCurrentParam = 0;
	m_nCurrentParamText = 0;
	m_nCurrentParamInputName = 0;
	
} 

void StudioWeb_TemplateParamQuery::setParam(const Tools_DynamicUTF8String &sParamText)
{
	++m_nParams;	
	
	m_ParamText[m_nParams] = sParamText;	

	m_ParamInputName[m_nParams] = (SAPDB_UTF8*)"T";
	//sBuffer contains a number, which can be represented in ascii7 => cast to (SAPDB_UTF8*) is valid
	char	sBuffer[64];
	sprintf(sBuffer,"%d",m_nParams);				
	m_ParamInputName[m_nParams].Append((SAPDB_UTF8*)sBuffer);	

	
}



SAPDB_Int2 StudioWeb_TemplateParamQuery::askForWriteCount(const Tools_DynamicUTF8String &szName)
{
  SAPDB_Int2 nReturn = 0;

  if (szName.Compare( OBJ_ONEPARAM) == 0) {
    //nReturn = (m_nCurrentParam < m_nParams) ? 1 : 0;
	  nReturn = m_nParams;
    ++m_nCurrentParam;
  }
  else if (szName.Compare( OBJ_ONEPARAMTEXT) == 0) {
    nReturn = 1;
  }
  else if (szName.Compare( OBJ_ONEPARAMINPUTNAME) == 0) {
    nReturn = 1;
  } // end if
  else if (szName.Compare( OBJ_PARAMSTATEMENT) == 0) {
    nReturn = 1;
  } // end if
  

  return nReturn;
} 


Tools_DynamicUTF8String StudioWeb_TemplateParamQuery::askForValue (const Tools_DynamicUTF8String &szName)
{
  
  if (szName.Compare( OBJ_ONEPARAM) == 0) {

	  return Tools_DynamicUTF8String();	  
  } 
  else if (szName.Compare( OBJ_ONEPARAMTEXT) == 0) {

	  ++m_nCurrentParamText;
	  return  m_ParamText[m_nCurrentParamText];	  
  } 
  else if (szName.Compare( OBJ_ONEPARAMINPUTNAME) == 0) {

	  ++m_nCurrentParamInputName;	
	  return m_ParamInputName[m_nCurrentParamInputName];
  }
  else if (szName.Compare( OBJ_PARAMSTATEMENT) == 0) {

    return m_sStatement;
  } 	

  return Tools_DynamicUTF8String();
}

void StudioWeb_TemplateParamQuery::resetStartValues ()
{
	m_nCurrentParam = 0;
	m_nCurrentParamText = 0;
	m_nCurrentParamInputName = 0;
}
